#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
#  File-Name:       replicationFile_immigDiscrDilemma.r   		       		
#  Date started:    25/04/04                			
#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
# Set-up session and load data ----
#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
pkgs <- c("ggplot2","tidyverse","dplyr",'conflicted','xtable','estimatr',
  'foreign','summarytools','cregg')
for (pkg in pkgs) library(pkg,character.only=T)
conflict_prefer("filter", "dplyr")
conflict_prefer("lag", "dplyr")

# Load respondent-level data
data <- read.csv('data_immigDiscrDilemma.csv') %>%
  mutate(treatment=factor(treatment,
    levels=c('Control','Loyalty','Caring','Exploitation')))

# Load respondent-task-level data
dataLong <- read.csv('dataLong_immigDiscrDilemma.csv') %>%
  mutate(treatment=factor(treatment,
    levels=c('Control','Loyalty','Caring','Exploitation')),
  across(where(is.character), as.factor)) 

#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
# Figure 1: ----
#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
r <- data %>%  
  filter(!is.na(weight2)) %>% 
  droplevels() %>% 
  pivot_longer(cols=c(gratitude,legalrightsvisa,legalrightsundoc)) %>% 
  group_by(name) %>% 
  do(lm_robust(value~treatment,data=.,weights=weight2,
    clusters=resid) %>% tidy()) %>% 
  filter(term!='(Intercept)') %>%
  mutate(
    name=factor(recode(name,'gratitude'='Gratitude',
      'legalrightsvisa'='Rights, Legal',
      'legalrightsundoc'='Rights, Undoc'),
    levels=c('Rights, Undoc','Rights, Legal','Gratitude')),
        l2=estimate-1.6*std.error,u2=estimate+1.6*std.error,
    term=factor(str_remove(term,'treatment'),
      levels=c('Loyalty','Caring','Exploitation'))) %>%
  filter(name!='Gratitude')

pdf('figure1.pdf',height=3,width=4)
r %>%
  ggplot(aes(x=name,y=estimate,ymin=conf.low,ymax=conf.high,color=term,fill=term)) + 
  geom_hline(aes(yintercept=0),color='gray') + 
  geom_pointrange(position=position_dodge(width=.5),size=.2,shape=21) + 
  geom_pointrange(aes(ymin=l2,ymax=u2),position=position_dodge(width=.5),
    linewidth=1,size=.2,shape=21) +
  coord_flip() + 
  scale_color_manual(values=c('black','gray','darkgray')) +
  scale_fill_manual(values=c('black','white','darkgray')) +
  labs(x='',y='Average treatment effect on support') + 
  theme_bw() +
  theme(legend.position='bottom',legend.title=element_blank())
dev.off()

#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
# Figure 2: ----
#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
r <- dataLong %>% 
  filter(!is.na(weight2)) %>% 
  droplevels() %>% 
  cj(act ~ gender + legalStatus + country + riskExposure + occupation, 
     id= ~resid, by= ~treatment,estimate='mm_differences',weights= ~weight2) %>%
  mutate(
    l2=estimate-1.6*std.error,
    u2=estimate+1.6*std.error,
    feature=recode(feature,
      'gender'='Gender',
      'legalStatus'='Legal status',
      'country'='Origin',
      'riskExposure'='Risk Exposure',
      'occupation'='Occupation'))

ateOverall <- dataLong %>% 
  filter(!is.na(weight2)) %>% 
  droplevels() %>%  
  group_by(treatment) %>% 
  summarise(act=mean(act)) %>% 
  mutate(ate=act-lag(act)) 

pdf('figure2.pdf',height=7,width=4)
r %>%
  ggplot(aes(x=level,y=estimate,ymin=lower,ymax=upper,color=treatment,
    fill=treatment)) + 
  geom_hline(aes(yintercept=0),color='black') + 
  geom_hline(aes(yintercept=unlist(ateOverall[2,3])),linetype=3) + 
  facet_grid(feature~.,scale='free') +
  geom_pointrange(position=position_dodge(width=.5),size=.2,shape=21) + 
  geom_pointrange(aes(ymin=l2,ymax=u2),position=position_dodge(width=.5),
    linewidth=1,size=.2,shape=21) +
  coord_flip() + 
  scale_color_manual(values=c('black','gray','darkgray')) +
  scale_fill_manual(values=c('black','white','darkgray')) +
  labs(x='',y='Average treatment effect on support\n(Difference in marginal means)') + 
  theme_bw() + 
  theme(legend.position='bottom',legend.title=element_blank())
dev.off()

#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
# Figure 3: ----
#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
r <- dataLong %>% 
  filter(treatment=='Control'|treatment=='Loyalty') %>%
  group_by(gender,country) %>% 
  do(lm_robust(act~treatment,data=.,weights=weight2,clusters=resid) %>% 
    tidy()) %>%
  filter(term!='(Intercept)') %>%
  mutate(gender=ifelse(gender=='man','Men','Women'),
    l2=estimate-1.6*std.error,u2=estimate+1.6*std.error)

pdf('figure3.pdf',height=4)
r %>%
  ggplot(aes(x=gender,y=estimate,ymin=conf.low,ymax=conf.high,color=country,
    fill=country)) +
  geom_hline(aes(yintercept=0),color='black') + 
  geom_pointrange(position=position_dodge(width=.5),size=.2,shape=21) + 
  geom_pointrange(aes(ymin=l2,ymax=u2),position=position_dodge(width=.5),
    linewidth=1,size=.2,shape=21) +
  coord_flip() +
  scale_color_manual(values=c('black','gray','darkgray','steelblue1','blue','steelblue3')) +
  scale_fill_manual(values=c('black','white','darkgray','steelblue1','blue','steelblue3')) +
  labs(x='',y='Support') + 
  theme_bw() + 
  theme(legend.position='bottom',legend.title=element_blank())
dev.off()

# Statistics in the text
dataLong %>% 
  filter(treatment=='Control'|treatment=='Loyalty') %>%
  group_by(country) %>% 
  do(lm_robust(act~treatment*gender,data=.,weights=weight2,clusters=resid) %>% 
    tidy()) %>% 
  filter(term=='treatmentLoyalty:genderwoman') 

dataLong %>% 
  filter(treatment=='Control') %>%
  group_by(country) %>% 
  do(lm_robust(act~gender,data=.,weights=weight2,clusters=resid) %>% 
    tidy()) 

#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
# Figure 4: ----
#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
r <- dataLong %>% 
  filter(!is.na(weight2)) %>% 
  droplevels() %>% 
  cj(act~occupation,id=~resid,by=~treatment,estimate='amce',weights= ~weight2) %>% 
  mutate(l2=estimate-1.6*std.error,u2=estimate+1.6*std.error)

pdf('figure4.pdf',height=3)
r %>%
  ggplot(aes(x=level,y=estimate,ymin=lower,ymax=upper,color=treatment,
    fill=treatment)) +
  geom_hline(aes(yintercept=0),color='black') + 
  geom_pointrange(position=position_dodge(width=.5),size=.2,shape=21) + 
  geom_pointrange(aes(ymin=l2,ymax=u2),position=position_dodge(width=.5),
    linewidth=1,size=.2,shape=21) +
  coord_flip() +
  scale_color_manual(values=c('black','gray','darkgray','steelblue1')) +
  scale_fill_manual(values=c('black','white','darkgray','steelblue1')) +
  labs(x='',y='Average marginal component effect on support') + 
  theme_bw() + 
  theme(legend.position='bottom',legend.title=element_blank())
dev.off()

#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#